pub enum AspectExpressionError {
AddingAspect(AspectAddingError),
InvalidAspectDefault(Box<str>),
}Expand description
Represents errors that can occur when parsing a single aspect default expression.
Variants
AddingAspect(AspectAddingError)
Error while adding a default aspect from the aspects file.
InvalidAspectDefault(Box<str>)
An invalid aspect default was found in the aspects file.